# sqliteparser
A parser for SQLite's dialect of SQL. Built for use by [isqlite](https://github.com/iafisher/isqlite).

## Installation
Install sqliteparser with Pip:

```shell
$ pip install sqliteparser
```

## Documentation
Documentation is available at https://sqliteparser.readthedocs.io/en/latest/.
